==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/PostAuthSessionPolicyRuleRunWorkflow.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.EntityRiskPolicyRuleActionRunWorkflowWorkflow;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PostAuthSessionPolicyRuleRunWorkflow
 */
@JsonPropertyOrder({ PostAuthSessionPolicyRuleRunWorkflow.JSON_PROPERTY_ACTION,
        PostAuthSessionPolicyRuleRunWorkflow.JSON_PROPERTY_WORKFLOW })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PostAuthSessionPolicyRuleRunWorkflow implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * Gets or Sets action
     */
    public enum ActionEnum {
        RUN_WORKFLOW("RUN_WORKFLOW"),

        UNKNOWN_DEFAULT_OPEN_API("unknown_default_open_api");

        private String value;

        ActionEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static ActionEnum fromValue(String value) {
            for (ActionEnum b : ActionEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_ACTION = "action";
    private ActionEnum action;

    public static final String JSON_PROPERTY_WORKFLOW = "workflow";
    private EntityRiskPolicyRuleActionRunWorkflowWorkflow workflow;

    public PostAuthSessionPolicyRuleRunWorkflow() {
    }

    public PostAuthSessionPolicyRuleRunWorkflow action(ActionEnum action) {

        this.action = action;
        return this;
    }

    /**
     * Get action
     *
     * @return action
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ActionEnum getAction() {
        return action;
    }

    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAction(ActionEnum action) {
        this.action = action;
    }

    public PostAuthSessionPolicyRuleRunWorkflow workflow(EntityRiskPolicyRuleActionRunWorkflowWorkflow workflow) {

        this.workflow = workflow;
        return this;
    }

    /**
     * Get workflow
     *
     * @return workflow
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_WORKFLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public EntityRiskPolicyRuleActionRunWorkflowWorkflow getWorkflow() {
        return workflow;
    }

    @JsonProperty(JSON_PROPERTY_WORKFLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setWorkflow(EntityRiskPolicyRuleActionRunWorkflowWorkflow workflow) {
        this.workflow = workflow;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PostAuthSessionPolicyRuleRunWorkflow postAuthSessionPolicyRuleRunWorkflow = (PostAuthSessionPolicyRuleRunWorkflow) o;
        return Objects.equals(this.action, postAuthSessionPolicyRuleRunWorkflow.action)
                && Objects.equals(this.workflow, postAuthSessionPolicyRuleRunWorkflow.workflow);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(action, workflow);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PostAuthSessionPolicyRuleRunWorkflow {\n");
        sb.append("    action: ").append(toIndentedString(action)).append("\n");
        sb.append("    workflow: ").append(toIndentedString(workflow)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/PostAuthSessionPolicyRuleRunWorkflow.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.EntityRiskPolicyRuleActionRunWorkflowWorkflow;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PostAuthSessionPolicyRuleRunWorkflow
 */
@JsonPropertyOrder({ PostAuthSessionPolicyRuleRunWorkflow.JSON_PROPERTY_ACTION,
        PostAuthSessionPolicyRuleRunWorkflow.JSON_PROPERTY_WORKFLOW })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PostAuthSessionPolicyRuleRunWorkflow implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * Gets or Sets action
     */
    public enum ActionEnum {
        RUN_WORKFLOW("RUN_WORKFLOW"),

        UNKNOWN_DEFAULT_OPEN_API("unknown_default_open_api");

        private String value;

        ActionEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static ActionEnum fromValue(String value) {
            for (ActionEnum b : ActionEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_ACTION = "action";
    private ActionEnum action;

    public static final String JSON_PROPERTY_WORKFLOW = "workflow";
    private EntityRiskPolicyRuleActionRunWorkflowWorkflow workflow;

    public PostAuthSessionPolicyRuleRunWorkflow() {
    }

    public PostAuthSessionPolicyRuleRunWorkflow action(ActionEnum action) {

        this.action = action;
        return this;
    }

    /**
     * Get action
     *
     * @return action
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public ActionEnum getAction() {
        return action;
    }

    @JsonProperty(JSON_PROPERTY_ACTION)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAction(ActionEnum action) {
        this.action = action;
    }

    public PostAuthSessionPolicyRuleRunWorkflow workflow(EntityRiskPolicyRuleActionRunWorkflowWorkflow workflow) {

        this.workflow = workflow;
        return this;
    }

    /**
     * Get workflow
     *
     * @return workflow
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_WORKFLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public EntityRiskPolicyRuleActionRunWorkflowWorkflow getWorkflow() {
        return workflow;
    }

    @JsonProperty(JSON_PROPERTY_WORKFLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setWorkflow(EntityRiskPolicyRuleActionRunWorkflowWorkflow workflow) {
        this.workflow = workflow;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PostAuthSessionPolicyRuleRunWorkflow postAuthSessionPolicyRuleRunWorkflow = (PostAuthSessionPolicyRuleRunWorkflow) o;
        return Objects.equals(this.action, postAuthSessionPolicyRuleRunWorkflow.action)
                && Objects.equals(this.workflow, postAuthSessionPolicyRuleRunWorkflow.workflow);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(action, workflow);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PostAuthSessionPolicyRuleRunWorkflow {\n");
        sb.append("    action: ").append(toIndentedString(action)).append("\n");
        sb.append("    workflow: ").append(toIndentedString(workflow)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
